pub struct ArrowReaderBuilder { /* private fields */ }Expand description
Builder to create ArrowReader
Implementations
Sourceimpl ArrowReaderBuilder
impl ArrowReaderBuilder
Sourcepub fn with_data_file_concurrency_limit(self, val: usize) -> Self
pub fn with_data_file_concurrency_limit(self, val: usize) -> Self
Sets the max number of in flight data files that are being fetched
Sourcepub fn with_batch_size(self, batch_size: usize) -> Self
pub fn with_batch_size(self, batch_size: usize) -> Self
Sets the desired size of batches in the response to something other than the default
Sourcepub fn with_row_group_filtering_enabled(
self,
row_group_filtering_enabled: bool,
) -> Self
pub fn with_row_group_filtering_enabled( self, row_group_filtering_enabled: bool, ) -> Self
Determines whether to enable row group filtering.
Sourcepub fn with_row_selection_enabled(self, row_selection_enabled: bool) -> Self
pub fn with_row_selection_enabled(self, row_selection_enabled: bool) -> Self
Determines whether to enable row selection.
Sourcepub fn with_metadata_size_hint(self, metadata_size_hint: usize) -> Self
pub fn with_metadata_size_hint(self, metadata_size_hint: usize) -> Self
Provide a hint as to the number of bytes to prefetch for parsing the Parquet metadata
This hint can help reduce the number of fetch requests. For more details see the ParquetMetaDataReader documentation.
Sourcepub fn with_range_coalesce_bytes(self, range_coalesce_bytes: u64) -> Self
pub fn with_range_coalesce_bytes(self, range_coalesce_bytes: u64) -> Self
Sets the gap threshold for merging nearby byte ranges into a single request. Ranges with gaps smaller than this value will be coalesced.
Defaults to 1 MiB, matching object_store’s OBJECT_STORE_COALESCE_DEFAULT.
Sourcepub fn with_range_fetch_concurrency(
self,
range_fetch_concurrency: usize,
) -> Self
pub fn with_range_fetch_concurrency( self, range_fetch_concurrency: usize, ) -> Self
Sets the maximum number of merged byte ranges to fetch concurrently.
Defaults to 10, matching object_store’s OBJECT_STORE_COALESCE_PARALLEL.
Sourcepub fn build(self) -> ArrowReader
pub fn build(self) -> ArrowReader
Build the ArrowReader.