pub enum CompressionCodec {
None,
Lz4,
Lz4Raw,
Zstd(u8),
Gzip(u8),
Brotli(u8),
Lzo,
Snappy,
}Expand description
Data compression formats
Variants
None
No compression
Lz4
LZ4 single compression frame with content size present
Lz4Raw
LZ4 raw block compression (no frame). Used by Parquet as lz4_raw.
Zstd(u8)
Zstandard single compression frame with content size present.
Level range is 0–22, where 0 means default compression level (not no compression).
Use CompressionCodec::zstd_default to construct with the default level.
Gzip(u8)
Gzip compression. Level range is 0–9, where 0 means no compression.
Use CompressionCodec::gzip_default to construct with the default level.
Brotli(u8)
Brotli compression. Level range is 0–11.
Use CompressionCodec::brotli_default to construct with the default level.
Lzo
LZO compression
Snappy
Snappy compression
Implementations
Sourceimpl CompressionCodec
impl CompressionCodec
Sourcepub const fn zstd_default() -> Self
pub const fn zstd_default() -> Self
Returns a Zstd codec with the default compression level.
Sourcepub const fn gzip_default() -> Self
pub const fn gzip_default() -> Self
Returns a Gzip codec with the default compression level.
Sourcepub const fn brotli_default() -> Self
pub const fn brotli_default() -> Self
Returns a Brotli codec with the default compression level.