pub struct FileScanTask { /* private fields */ }Expand description
A task to scan part of file.
Implementations
Sourceimpl FileScanTask
impl FileScanTask
Sourcepub fn builder() -> FileScanTaskBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> FileScanTaskBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building FileScanTask.
On the builder, call .file_size_in_bytes(...), .start(...), .length(...), .record_count(...)(optional), .first_row_id(...)(optional), .data_sequence_number(...)(optional), .data_file_path(...), .data_file_format(...), .schema(...), .project_field_ids(...), .predicate(...)(optional), .deletes(...)(optional), .partition(...)(optional), .partition_spec(...)(optional), .name_mapping(...)(optional), .unified_partition_type(...)(optional), .case_sensitive(...), .key_metadata(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FileScanTask.
Sourceimpl FileScanTask
impl FileScanTask
Sourcepub fn file_size_in_bytes(&self) -> u64
pub fn file_size_in_bytes(&self) -> u64
Returns the total size of the data file in bytes.
Sourcepub fn record_count(&self) -> Option<u64>
pub fn record_count(&self) -> Option<u64>
Returns the number of records in the file when the whole file is scanned.
Sourcepub fn first_row_id(&self) -> Option<i64>
pub fn first_row_id(&self) -> Option<i64>
Returns the first row id assigned to the data file.
Sourcepub fn data_sequence_number(&self) -> Option<i64>
pub fn data_sequence_number(&self) -> Option<i64>
Returns the data sequence number of the file.
Sourcepub fn data_file_path(&self) -> &str
pub fn data_file_path(&self) -> &str
Returns the data file path of this file scan task.
Sourcepub fn data_file_format(&self) -> DataFileFormat
pub fn data_file_format(&self) -> DataFileFormat
Returns the format of the data file.
Sourcepub fn schema_ref(&self) -> SchemaRef
pub fn schema_ref(&self) -> SchemaRef
Returns the schema of this file scan task as a SchemaRef.
Sourcepub fn project_field_ids(&self) -> &[i32]
pub fn project_field_ids(&self) -> &[i32]
Returns the project field id of this file scan task.
Sourcepub fn predicate(&self) -> Option<&BoundPredicate>
pub fn predicate(&self) -> Option<&BoundPredicate>
Returns the predicate of this file scan task.
Sourcepub fn deletes(&self) -> &[FileScanTaskDeleteFile]
pub fn deletes(&self) -> &[FileScanTaskDeleteFile]
Returns the delete files that may need to be applied to the data file.
Sourcepub fn partition_spec(&self) -> Option<&Arc<PartitionSpec>>
pub fn partition_spec(&self) -> Option<&Arc<PartitionSpec>>
Returns the partition spec for the data file.
Sourcepub fn name_mapping(&self) -> Option<&Arc<NameMapping>>
pub fn name_mapping(&self) -> Option<&Arc<NameMapping>>
Returns the name mapping used to resolve field ids.
Sourcepub fn unified_partition_type(&self) -> Option<&Arc<StructType>>
pub fn unified_partition_type(&self) -> Option<&Arc<StructType>>
Returns the unified partition type across all table partition specs.
Sourcepub fn case_sensitive(&self) -> bool
pub fn case_sensitive(&self) -> bool
Returns whether names are treated as case-sensitive.
Sourcepub fn key_metadata(&self) -> Option<&[u8]>
pub fn key_metadata(&self) -> Option<&[u8]>
Returns the key metadata for the encrypted data file.