pub struct FileScanTaskDeleteFile { /* private fields */ }Expand description
A task to scan part of file.
Implementations
Sourceimpl FileScanTaskDeleteFile
impl FileScanTaskDeleteFile
Sourcepub fn builder() -> FileScanTaskDeleteFileBuilder<((), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> FileScanTaskDeleteFileBuilder<((), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building FileScanTaskDeleteFile.
On the builder, call .file_path(...), .file_size_in_bytes(...), .file_type(...), .file_format(...), .partition_spec_id(...), .equality_ids(...)(optional), .referenced_data_file(...)(optional), .content_offset(...)(optional), .content_size_in_bytes(...)(optional), .record_count(...)(optional), .key_metadata(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FileScanTaskDeleteFile.
Sourceimpl FileScanTaskDeleteFile
impl FileScanTaskDeleteFile
Sourcepub fn file_size_in_bytes(&self) -> u64
pub fn file_size_in_bytes(&self) -> u64
Returns the total size of the delete file in bytes.
Sourcepub fn file_type(&self) -> DataContentType
pub fn file_type(&self) -> DataContentType
Returns the delete file content type.
Sourcepub fn file_format(&self) -> DataFileFormat
pub fn file_format(&self) -> DataFileFormat
Returns the delete file format.
Sourcepub fn partition_spec_id(&self) -> i32
pub fn partition_spec_id(&self) -> i32
Returns the partition spec id.
Sourcepub fn equality_ids(&self) -> Option<&[i32]>
pub fn equality_ids(&self) -> Option<&[i32]>
Returns the equality field ids for an equality delete file.
Sourcepub fn referenced_data_file(&self) -> Option<&str>
pub fn referenced_data_file(&self) -> Option<&str>
Returns the referenced data file path.
Sourcepub fn content_offset(&self) -> Option<u64>
pub fn content_offset(&self) -> Option<u64>
Returns the deletion vector blob offset.
Sourcepub fn content_size_in_bytes(&self) -> Option<u64>
pub fn content_size_in_bytes(&self) -> Option<u64>
Returns the deletion vector blob size in bytes.
Sourcepub fn record_count(&self) -> Option<u64>
pub fn record_count(&self) -> Option<u64>
Returns the number of records in the delete file.
Sourcepub fn key_metadata(&self) -> Option<&[u8]>
pub fn key_metadata(&self) -> Option<&[u8]>
Returns the key metadata for the encrypted delete file.