pub struct SensitiveString(/* private fields */);Expand description
A string-like type containing sensitive information such as passwords or tokens.
It is redacted from debug logs and automatically zeroized.
Example
use iceberg::sensitive::SensitiveString;
let sensitive_value = "my-pw-12345";
let sensitive_string = SensitiveString::from(sensitive_value.to_string());
// Not contained in debug logs.
assert!(!format!("{:?}", sensitive_string).contains(sensitive_value));Display
SensitiveString does not implement [Display] to prevent bugs like:
ⓘ
// We don't want to send a redacted `Bearer: *****`.
let auth_header = format!("Bearer {}", SensitiveString::from("token".to_string()));Instead use an explicit SensitiveString::expose when you need it:
let auth_header = format!(
"Bearer: {}",
SensitiveString::from("token".to_string()).expose()
);Implementations