pub struct ManifestReader { /* private fields */ }Expand description
Reads a manifest file referenced by a manifest list entry, transparently decrypting it when the entry records key metadata.
Implementations
Sourceimpl ManifestReader
impl ManifestReader
Sourcepub async fn read(self, manifest_file: &ManifestFile) -> Result<Manifest>
pub async fn read(self, manifest_file: &ManifestFile) -> Result<Manifest>
Read, decrypt, parse and return the manifest described by
manifest_file.