pub struct TableProperties<'properties> { /* private fields */ }Expand description
Typed view over the properties of a table.
Implementations
Sourceimpl<'properties> TableProperties<'properties>
impl<'properties> TableProperties<'properties>
Sourcepub fn new(properties: &'properties HashMap<String, String>) -> Self
pub fn new(properties: &'properties HashMap<String, String>) -> Self
Creates a property view without parsing any values.
Sourcepub fn commit_num_retries(&self) -> Result<usize>
pub fn commit_num_retries(&self) -> Result<usize>
The number of times to retry a commit.
Sourcepub fn commit_min_retry_wait_ms(&self) -> Result<u64>
pub fn commit_min_retry_wait_ms(&self) -> Result<u64>
The minimum wait time between retries.
Sourcepub fn commit_max_retry_wait_ms(&self) -> Result<u64>
pub fn commit_max_retry_wait_ms(&self) -> Result<u64>
The maximum wait time between retries.
Sourcepub fn commit_total_retry_timeout_ms(&self) -> Result<u64>
pub fn commit_total_retry_timeout_ms(&self) -> Result<u64>
The total timeout for commit retries.
Sourcepub fn write_format_default(&self) -> Result<String>
pub fn write_format_default(&self) -> Result<String>
The default format for files.
Sourcepub fn write_target_file_size_bytes(&self) -> Result<usize>
pub fn write_target_file_size_bytes(&self) -> Result<usize>
The target file size for files.
Sourcepub fn write_metadata_path(&self) -> Result<Option<String>>
pub fn write_metadata_path(&self) -> Result<Option<String>>
Base directory for metadata files (manifests, manifest lists), with any
trailing slash trimmed. None if write.metadata.path is not set.
Sourcepub fn metadata_compression_codec(&self) -> Result<CompressionCodec>
pub fn metadata_compression_codec(&self) -> Result<CompressionCodec>
Compression codec for metadata files (JSON)
Sourcepub fn write_datafusion_fanout_enabled(&self) -> Result<bool>
pub fn write_datafusion_fanout_enabled(&self) -> Result<bool>
Whether to use FanoutWriter for partitioned tables.
Sourcepub fn gc_enabled(&self) -> Result<bool>
pub fn gc_enabled(&self) -> Result<bool>
Whether garbage collection is enabled on drop.
When false, data files will not be deleted when a table is dropped.
Sourcepub fn max_snapshot_age_ms(&self) -> Result<i64>
pub fn max_snapshot_age_ms(&self) -> Result<i64>
Default maximum age of a snapshot to keep when expiring snapshots.
Sourcepub fn min_snapshots_to_keep(&self) -> Result<usize>
pub fn min_snapshots_to_keep(&self) -> Result<usize>
Default minimum number of snapshots to keep per branch when expiring snapshots.
Sourcepub fn max_ref_age_ms(&self) -> Result<i64>
pub fn max_ref_age_ms(&self) -> Result<i64>
Default maximum age of a snapshot reference to keep when expiring snapshots.
Sourcepub fn cdc_enabled(&self) -> Result<bool>
pub fn cdc_enabled(&self) -> Result<bool>
Whether content-defined chunking is enabled.
true only when write.parquet.content-defined-chunking.enabled = "true".
Sourcepub fn cdc_min_chunk_size(&self) -> Result<usize>
pub fn cdc_min_chunk_size(&self) -> Result<usize>
Content-defined chunking minimum chunk size in bytes.
Sourcepub fn cdc_max_chunk_size(&self) -> Result<usize>
pub fn cdc_max_chunk_size(&self) -> Result<usize>
Content-defined chunking maximum chunk size in bytes.
Sourcepub fn cdc_norm_level(&self) -> Result<i32>
pub fn cdc_norm_level(&self) -> Result<i32>
Content-defined chunking normalization level (gearhash bit adjustment).
Sourcepub fn parquet_compression_codec(&self) -> Result<CompressionCodec>
pub fn parquet_compression_codec(&self) -> Result<CompressionCodec>
Parquet compression codec for data files, with the resolved compression
level folded in (from write.parquet.compression-level, or the codec’s
default when unset).
Sourcepub fn parquet_row_group_size_bytes(&self) -> Result<usize>
pub fn parquet_row_group_size_bytes(&self) -> Result<usize>
Approximate maximum Parquet row group size in bytes.
Sourcepub fn parquet_page_size_bytes(&self) -> Result<usize>
pub fn parquet_page_size_bytes(&self) -> Result<usize>
Approximate maximum Parquet data page size in bytes.
Sourcepub fn parquet_page_row_limit(&self) -> Result<usize>
pub fn parquet_page_row_limit(&self) -> Result<usize>
Maximum number of rows per Parquet data page.
Sourcepub fn parquet_dict_size_bytes(&self) -> Result<usize>
pub fn parquet_dict_size_bytes(&self) -> Result<usize>
Approximate maximum Parquet dictionary page size in bytes.
Sourcepub fn encryption_key_id(&self) -> Result<Option<String>>
pub fn encryption_key_id(&self) -> Result<Option<String>>
The master key id used to encrypt this table’s manifest list and data
files. None if encryption.key-id is not set.
Sourcepub fn encryption_data_key_length(&self) -> Result<usize>
pub fn encryption_data_key_length(&self) -> Result<usize>
The encryption data encryption key length in bytes.
Sourcepub fn write_data_location(&self) -> Result<Option<String>>
pub fn write_data_location(&self) -> Result<Option<String>>
Base directory for data files, with any trailing slash trimmed.
Sourcepub fn write_folder_storage_location(&self) -> Result<Option<String>>
pub fn write_folder_storage_location(&self) -> Result<Option<String>>
Deprecated table property for data file write location, with any trailing slash trimmed.
Property will be removed at a later date.
Superseded by TableProperties::write_data_location.
Sourcepub fn write_object_storage_location(&self) -> Result<Option<String>>
pub fn write_object_storage_location(&self) -> Result<Option<String>>
Deprecated table property for data file write location for object storage location generator, with any trailing slash trimmed.
Property will be removed at a later date.
Superseded by TableProperties::write_data_location.
Sourcepub fn write_object_storage_partitioned_paths(&self) -> Result<bool>
pub fn write_object_storage_partitioned_paths(&self) -> Result<bool>
Whether partition values are included in object storage paths.
Sourcepub fn default_name_mapping(&self) -> Result<Option<NameMapping>>
pub fn default_name_mapping(&self) -> Result<Option<NameMapping>>
The table’s default name mapping, used to assign field ids when reading data files
that carry no field id metadata. None if schema.name-mapping.default is not set.
Sourceimpl TableProperties<'_>
impl TableProperties<'_>
Sourcepub const PROPERTY_FORMAT_VERSION: &'static str = "format-version"
pub const PROPERTY_FORMAT_VERSION: &'static str = "format-version"
Reserved table property for table format version.
Iceberg will default a new table’s format version to the latest stable and recommended version. This reserved property keyword allows users to override the Iceberg format version of the table metadata.
If this table property exists when creating a table, the table will use the specified format version. If a table updates this property, it will try to upgrade to the specified format version.
Sourcepub const PROPERTY_UUID: &'static str = "uuid"
pub const PROPERTY_UUID: &'static str = "uuid"
Reserved table property for table UUID.
Sourcepub const PROPERTY_SNAPSHOT_COUNT: &'static str = "snapshot-count"
pub const PROPERTY_SNAPSHOT_COUNT: &'static str = "snapshot-count"
Reserved table property for the total number of snapshots.
Sourcepub const PROPERTY_CURRENT_SNAPSHOT_SUMMARY: &'static str = "current-snapshot-summary"
pub const PROPERTY_CURRENT_SNAPSHOT_SUMMARY: &'static str = "current-snapshot-summary"
Reserved table property for current snapshot summary.
Sourcepub const PROPERTY_CURRENT_SNAPSHOT_ID: &'static str = "current-snapshot-id"
pub const PROPERTY_CURRENT_SNAPSHOT_ID: &'static str = "current-snapshot-id"
Reserved table property for current snapshot id.
Sourcepub const PROPERTY_CURRENT_SNAPSHOT_TIMESTAMP: &'static str = "current-snapshot-timestamp-ms"
pub const PROPERTY_CURRENT_SNAPSHOT_TIMESTAMP: &'static str = "current-snapshot-timestamp-ms"
Reserved table property for current snapshot timestamp.
Sourcepub const PROPERTY_CURRENT_SCHEMA: &'static str = "current-schema"
pub const PROPERTY_CURRENT_SCHEMA: &'static str = "current-schema"
Reserved table property for the JSON representation of current schema.
Sourcepub const PROPERTY_DEFAULT_PARTITION_SPEC: &'static str = "default-partition-spec"
pub const PROPERTY_DEFAULT_PARTITION_SPEC: &'static str = "default-partition-spec"
Reserved table property for the JSON representation of current(default) partition spec.
Sourcepub const PROPERTY_DEFAULT_SORT_ORDER: &'static str = "default-sort-order"
pub const PROPERTY_DEFAULT_SORT_ORDER: &'static str = "default-sort-order"
Reserved table property for the JSON representation of current(default) sort order.
Sourcepub const PROPERTY_METADATA_PREVIOUS_VERSIONS_MAX: &'static str = "write.metadata.previous-versions-max"
pub const PROPERTY_METADATA_PREVIOUS_VERSIONS_MAX: &'static str = "write.metadata.previous-versions-max"
Property key for max number of previous versions to keep.
Sourcepub const PROPERTY_METADATA_PREVIOUS_VERSIONS_MAX_DEFAULT: usize = 100
pub const PROPERTY_METADATA_PREVIOUS_VERSIONS_MAX_DEFAULT: usize = 100
Default value for max number of previous versions to keep.
Sourcepub const PROPERTY_WRITE_PARTITION_SUMMARY_LIMIT: &'static str = "write.summary.partition-limit"
pub const PROPERTY_WRITE_PARTITION_SUMMARY_LIMIT: &'static str = "write.summary.partition-limit"
Property key for max number of partitions to keep summary stats for.
Sourcepub const PROPERTY_WRITE_PARTITION_SUMMARY_LIMIT_DEFAULT: u64 = 0
pub const PROPERTY_WRITE_PARTITION_SUMMARY_LIMIT_DEFAULT: u64 = 0
Default value for the max number of partitions to keep summary stats for.
Sourcepub const RESERVED_PROPERTIES: [&'static str; 9]
pub const RESERVED_PROPERTIES: [&'static str; 9]
Reserved Iceberg table properties list.
Reserved table properties are only used to control behaviors when creating or updating a table. The value of these properties are not persisted as a part of the table metadata.
Sourcepub const PROPERTY_COMMIT_NUM_RETRIES: &'static str = "commit.retry.num-retries"
pub const PROPERTY_COMMIT_NUM_RETRIES: &'static str = "commit.retry.num-retries"
Property key for number of commit retries.
Sourcepub const PROPERTY_COMMIT_NUM_RETRIES_DEFAULT: usize = 4
pub const PROPERTY_COMMIT_NUM_RETRIES_DEFAULT: usize = 4
Default value for number of commit retries.
Sourcepub const PROPERTY_COMMIT_MIN_RETRY_WAIT_MS: &'static str = "commit.retry.min-wait-ms"
pub const PROPERTY_COMMIT_MIN_RETRY_WAIT_MS: &'static str = "commit.retry.min-wait-ms"
Property key for minimum wait time (ms) between retries.
Sourcepub const PROPERTY_COMMIT_MIN_RETRY_WAIT_MS_DEFAULT: u64 = 100
pub const PROPERTY_COMMIT_MIN_RETRY_WAIT_MS_DEFAULT: u64 = 100
Default value for minimum wait time (ms) between retries.
Sourcepub const PROPERTY_COMMIT_MAX_RETRY_WAIT_MS: &'static str = "commit.retry.max-wait-ms"
pub const PROPERTY_COMMIT_MAX_RETRY_WAIT_MS: &'static str = "commit.retry.max-wait-ms"
Property key for maximum wait time (ms) between retries.
Sourcepub const PROPERTY_COMMIT_MAX_RETRY_WAIT_MS_DEFAULT: u64
pub const PROPERTY_COMMIT_MAX_RETRY_WAIT_MS_DEFAULT: u64
Default value for maximum wait time (ms) between retries.
Sourcepub const PROPERTY_COMMIT_TOTAL_RETRY_TIME_MS: &'static str = "commit.retry.total-timeout-ms"
pub const PROPERTY_COMMIT_TOTAL_RETRY_TIME_MS: &'static str = "commit.retry.total-timeout-ms"
Property key for total maximum retry time (ms).
Sourcepub const PROPERTY_COMMIT_TOTAL_RETRY_TIME_MS_DEFAULT: u64
pub const PROPERTY_COMMIT_TOTAL_RETRY_TIME_MS_DEFAULT: u64
Default value for total maximum retry time (ms).
Sourcepub const PROPERTY_DEFAULT_FILE_FORMAT: &'static str = "write.format.default"
pub const PROPERTY_DEFAULT_FILE_FORMAT: &'static str = "write.format.default"
Default file format for data files
Sourcepub const PROPERTY_DELETE_DEFAULT_FILE_FORMAT: &'static str = "write.delete.format.default"
pub const PROPERTY_DELETE_DEFAULT_FILE_FORMAT: &'static str = "write.delete.format.default"
Default file format for delete files
Sourcepub const PROPERTY_DEFAULT_FILE_FORMAT_DEFAULT: &'static str = "parquet"
pub const PROPERTY_DEFAULT_FILE_FORMAT_DEFAULT: &'static str = "parquet"
Default value for data file format
Sourcepub const PROPERTY_WRITE_TARGET_FILE_SIZE_BYTES: &'static str = "write.target-file-size-bytes"
pub const PROPERTY_WRITE_TARGET_FILE_SIZE_BYTES: &'static str = "write.target-file-size-bytes"
Target file size for newly written files.
Sourcepub const PROPERTY_WRITE_TARGET_FILE_SIZE_BYTES_DEFAULT: usize
pub const PROPERTY_WRITE_TARGET_FILE_SIZE_BYTES_DEFAULT: usize
Default target file size
Sourcepub const PROPERTY_WRITE_METADATA_PATH: &'static str = "write.metadata.path"
pub const PROPERTY_WRITE_METADATA_PATH: &'static str = "write.metadata.path"
Base location for metadata files (manifests, manifest lists, table metadata).
When unset, metadata files default to the metadata directory under the table
location.
Sourcepub const PROPERTY_DEFAULT_NAME_MAPPING: &'static str = "schema.name-mapping.default"
pub const PROPERTY_DEFAULT_NAME_MAPPING: &'static str = "schema.name-mapping.default"
Property key for the table’s default name mapping, stored as a JSON
NameMapping document.
Sourcepub const PROPERTY_METADATA_COMPRESSION_CODEC: &'static str = "write.metadata.compression-codec"
pub const PROPERTY_METADATA_COMPRESSION_CODEC: &'static str = "write.metadata.compression-codec"
Compression codec for metadata files (JSON)
Sourcepub const PROPERTY_METADATA_COMPRESSION_CODEC_DEFAULT: &'static str = "none"
pub const PROPERTY_METADATA_COMPRESSION_CODEC_DEFAULT: &'static str = "none"
Default metadata compression codec - uncompressed
Sourcepub const PROPERTY_DATAFUSION_WRITE_FANOUT_ENABLED: &'static str = "write.datafusion.fanout.enabled"
pub const PROPERTY_DATAFUSION_WRITE_FANOUT_ENABLED: &'static str = "write.datafusion.fanout.enabled"
Whether to use FanoutWriter for partitioned tables (handles unsorted data).
If false, uses ClusteredWriter (requires sorted data, more memory efficient).
Sourcepub const PROPERTY_DATAFUSION_WRITE_FANOUT_ENABLED_DEFAULT: bool = true
pub const PROPERTY_DATAFUSION_WRITE_FANOUT_ENABLED_DEFAULT: bool = true
Default value for fanout writer enabled
Sourcepub const PROPERTY_GC_ENABLED: &'static str = "gc.enabled"
pub const PROPERTY_GC_ENABLED: &'static str = "gc.enabled"
Property key for enabling garbage collection on drop.
When set to false, data files will not be deleted when a table is dropped.
Defaults to true.
Sourcepub const PROPERTY_GC_ENABLED_DEFAULT: bool = true
pub const PROPERTY_GC_ENABLED_DEFAULT: bool = true
Default value for gc.enabled
Sourcepub const PROPERTY_MAX_SNAPSHOT_AGE_MS: &'static str = "history.expire.max-snapshot-age-ms"
pub const PROPERTY_MAX_SNAPSHOT_AGE_MS: &'static str = "history.expire.max-snapshot-age-ms"
Property key for the default maximum age of a snapshot to keep when expiring snapshots.
Sourcepub const PROPERTY_MAX_SNAPSHOT_AGE_MS_DEFAULT: i64
pub const PROPERTY_MAX_SNAPSHOT_AGE_MS_DEFAULT: i64
Default value for history.expire.max-snapshot-age-ms (5 days).
Sourcepub const PROPERTY_MIN_SNAPSHOTS_TO_KEEP: &'static str = "history.expire.min-snapshots-to-keep"
pub const PROPERTY_MIN_SNAPSHOTS_TO_KEEP: &'static str = "history.expire.min-snapshots-to-keep"
Property key for the default minimum number of snapshots to keep when expiring snapshots.
Sourcepub const PROPERTY_MIN_SNAPSHOTS_TO_KEEP_DEFAULT: usize = 1
pub const PROPERTY_MIN_SNAPSHOTS_TO_KEEP_DEFAULT: usize = 1
Default value for history.expire.min-snapshots-to-keep.
Sourcepub const PROPERTY_MAX_REF_AGE_MS: &'static str = "history.expire.max-ref-age-ms"
pub const PROPERTY_MAX_REF_AGE_MS: &'static str = "history.expire.max-ref-age-ms"
Property key for the default maximum age of a snapshot reference to keep when expiring.
Sourcepub const PROPERTY_MAX_REF_AGE_MS_DEFAULT: i64 = i64::MAX
pub const PROPERTY_MAX_REF_AGE_MS_DEFAULT: i64 = i64::MAX
Default value for history.expire.max-ref-age-ms (effectively never expire refs).
Sourcepub const PROPERTY_PARQUET_CDC_ENABLED: &'static str = "write.parquet.content-defined-chunking.enabled"
pub const PROPERTY_PARQUET_CDC_ENABLED: &'static str = "write.parquet.content-defined-chunking.enabled"
Enable content-defined chunking with parquet defaults (or per-property overrides).
Sourcepub const PROPERTY_PARQUET_CDC_ENABLED_DEFAULT: bool = false
pub const PROPERTY_PARQUET_CDC_ENABLED_DEFAULT: bool = false
Default value for content-defined chunking enabled.
Sourcepub const PROPERTY_PARQUET_CDC_MIN_CHUNK_SIZE: &'static str = "write.parquet.content-defined-chunking.min-chunk-size"
pub const PROPERTY_PARQUET_CDC_MIN_CHUNK_SIZE: &'static str = "write.parquet.content-defined-chunking.min-chunk-size"
Minimum chunk size in bytes for content-defined chunking.
Sourcepub const PROPERTY_PARQUET_CDC_MIN_CHUNK_SIZE_DEFAULT: usize
pub const PROPERTY_PARQUET_CDC_MIN_CHUNK_SIZE_DEFAULT: usize
Default matches parquet::file::properties::DEFAULT_CDC_MIN_CHUNK_SIZE.
Sourcepub const PROPERTY_PARQUET_CDC_MAX_CHUNK_SIZE: &'static str = "write.parquet.content-defined-chunking.max-chunk-size"
pub const PROPERTY_PARQUET_CDC_MAX_CHUNK_SIZE: &'static str = "write.parquet.content-defined-chunking.max-chunk-size"
Maximum chunk size in bytes for content-defined chunking.
Sourcepub const PROPERTY_PARQUET_CDC_MAX_CHUNK_SIZE_DEFAULT: usize
pub const PROPERTY_PARQUET_CDC_MAX_CHUNK_SIZE_DEFAULT: usize
Default matches parquet::file::properties::DEFAULT_CDC_MAX_CHUNK_SIZE.
Sourcepub const PROPERTY_PARQUET_CDC_NORM_LEVEL: &'static str = "write.parquet.content-defined-chunking.norm-level"
pub const PROPERTY_PARQUET_CDC_NORM_LEVEL: &'static str = "write.parquet.content-defined-chunking.norm-level"
Normalization level (gearhash bit adjustment) for content-defined chunking.
Sourcepub const PROPERTY_PARQUET_CDC_NORM_LEVEL_DEFAULT: i32 = 0
pub const PROPERTY_PARQUET_CDC_NORM_LEVEL_DEFAULT: i32 = 0
Default matches parquet::file::properties::DEFAULT_CDC_NORM_LEVEL.
Sourcepub const PROPERTY_PARQUET_COMPRESSION_CODEC: &'static str = "write.parquet.compression-codec"
pub const PROPERTY_PARQUET_COMPRESSION_CODEC: &'static str = "write.parquet.compression-codec"
Compression codec for Parquet data files (e.g. zstd, gzip, snappy,
lz4, lz4_raw, brotli, lzo, uncompressed). The codec name is
parsed into a CompressionCodec when properties are parsed; the level’s
range is validated when the writer is built.
Sourcepub const PROPERTY_PARQUET_COMPRESSION_CODEC_DEFAULT: &'static str = "zstd"
pub const PROPERTY_PARQUET_COMPRESSION_CODEC_DEFAULT: &'static str = "zstd"
Default Parquet compression codec.
Sourcepub const PROPERTY_PARQUET_COMPRESSION_LEVEL: &'static str = "write.parquet.compression-level"
pub const PROPERTY_PARQUET_COMPRESSION_LEVEL: &'static str = "write.parquet.compression-level"
Compression level for Parquet data files, for codecs that take one
(gzip, zstd, brotli). When unset, the codec’s default level is used.
Sourcepub const PROPERTY_PARQUET_ROW_GROUP_SIZE_BYTES: &'static str = "write.parquet.row-group-size-bytes"
pub const PROPERTY_PARQUET_ROW_GROUP_SIZE_BYTES: &'static str = "write.parquet.row-group-size-bytes"
Approximate maximum size of a Parquet row group in bytes.
Sourcepub const PROPERTY_PARQUET_ROW_GROUP_SIZE_BYTES_DEFAULT: usize
pub const PROPERTY_PARQUET_ROW_GROUP_SIZE_BYTES_DEFAULT: usize
Default Parquet row group size in bytes.
Sourcepub const PROPERTY_PARQUET_PAGE_SIZE_BYTES: &'static str = "write.parquet.page-size-bytes"
pub const PROPERTY_PARQUET_PAGE_SIZE_BYTES: &'static str = "write.parquet.page-size-bytes"
Approximate maximum size of a Parquet data page in bytes.
Sourcepub const PROPERTY_PARQUET_PAGE_SIZE_BYTES_DEFAULT: usize
pub const PROPERTY_PARQUET_PAGE_SIZE_BYTES_DEFAULT: usize
Default Parquet page size in bytes.
Sourcepub const PROPERTY_PARQUET_PAGE_ROW_LIMIT: &'static str = "write.parquet.page-row-limit"
pub const PROPERTY_PARQUET_PAGE_ROW_LIMIT: &'static str = "write.parquet.page-row-limit"
Maximum number of rows per Parquet data page.
Sourcepub const PROPERTY_PARQUET_PAGE_ROW_LIMIT_DEFAULT: usize = 20000
pub const PROPERTY_PARQUET_PAGE_ROW_LIMIT_DEFAULT: usize = 20000
Default Parquet page row limit.
Sourcepub const PROPERTY_PARQUET_DICT_SIZE_BYTES: &'static str = "write.parquet.dict-size-bytes"
pub const PROPERTY_PARQUET_DICT_SIZE_BYTES: &'static str = "write.parquet.dict-size-bytes"
Approximate maximum size of the Parquet dictionary page in bytes.
Sourcepub const PROPERTY_PARQUET_DICT_SIZE_BYTES_DEFAULT: usize
pub const PROPERTY_PARQUET_DICT_SIZE_BYTES_DEFAULT: usize
Default Parquet dictionary page size in bytes.
Sourcepub const PROPERTY_ENCRYPTION_KEY_ID: &'static str = "encryption.key-id"
pub const PROPERTY_ENCRYPTION_KEY_ID: &'static str = "encryption.key-id"
Property key for the master key id used to encrypt the table’s manifest list and data files as defined in https://iceberg.apache.org/docs/nightly/encryption/.
Sourcepub const PROPERTY_ENCRYPTION_DATA_KEY_LENGTH: &'static str = "encryption.data-key-length"
pub const PROPERTY_ENCRYPTION_DATA_KEY_LENGTH: &'static str = "encryption.data-key-length"
Property key for the encryption data encryption key (DEK) length in bytes.
Sourcepub const PROPERTY_ENCRYPTION_DATA_KEY_LENGTH_DEFAULT: usize = 16
pub const PROPERTY_ENCRYPTION_DATA_KEY_LENGTH_DEFAULT: usize = 16
Default value for the encryption DEK length (16 bytes = AES-128).
Sourcepub const PROPERTY_WRITE_DATA_LOCATION: &'static str = "write.data.path"
pub const PROPERTY_WRITE_DATA_LOCATION: &'static str = "write.data.path"
Property key for the base directory for data files
Sourcepub const PROPERTY_WRITE_FOLDER_STORAGE_LOCATION: &'static str = "write.folder-storage.path"
pub const PROPERTY_WRITE_FOLDER_STORAGE_LOCATION: &'static str = "write.folder-storage.path"
Property key for deprecated TableProperties::write_folder_storage_location
Sourcepub const PROPERTY_WRITE_OBJECT_STORAGE_LOCATION: &'static str = "write.object-storage.path"
pub const PROPERTY_WRITE_OBJECT_STORAGE_LOCATION: &'static str = "write.object-storage.path"
Property key for deprecated object storage path, kept as a fallback for compatibility.
Sourcepub const PROPERTY_WRITE_OBJECT_STORAGE_PARTITIONED_PATHS: &'static str = "write.object-storage.partitioned-paths"
pub const PROPERTY_WRITE_OBJECT_STORAGE_PARTITIONED_PATHS: &'static str = "write.object-storage.partitioned-paths"
Property key for controlling whether partition values are included in object storage paths.
Sourcepub const PROPERTY_WRITE_OBJECT_STORAGE_PARTITIONED_PATHS_DEFAULT: bool = true
pub const PROPERTY_WRITE_OBJECT_STORAGE_PARTITIONED_PATHS_DEFAULT: bool = true
Default value for TableProperties::PROPERTY_WRITE_OBJECT_STORAGE_PARTITIONED_PATHS
Sourcepub fn data_encryption_key_size(&self) -> Result<AesKeySize>
pub fn data_encryption_key_size(&self) -> Result<AesKeySize>
The AES key size to use when generating data encryption keys, derived
from encryption.data-key-length.