pub struct MetadataLocation { /* private fields */ }Expand description
Helper for parsing a location of the format: <metadata-dir>/<version>-<uuid>.metadata.json
or with compression: <metadata-dir>/<version>-<uuid>.gz.metadata.json
<metadata-dir> is set to the write.metadata.path table property and
it defaults to the <location>/metadata when the property is not set.
Implementations
Sourceimpl MetadataLocation
impl MetadataLocation
Sourcepub fn try_new_with_metadata(metadata: &TableMetadata) -> Result<Self>
pub fn try_new_with_metadata(metadata: &TableMetadata) -> Result<Self>
Creates a completely new metadata location starting at version 0, deriving the
metadata directory and compression settings from the table metadata.
Only used for creating a new table. For updates, see with_next_version and
try_with_new_metadata.
Sourcepub fn with_next_version(&self) -> Self
pub fn with_next_version(&self) -> Self
Creates a new metadata location for an updated metadata file. Increments the version number and generates a new UUID.
Sourcepub fn try_with_new_metadata(
&self,
new_metadata: &TableMetadata,
) -> Result<Self>
pub fn try_with_new_metadata( &self, new_metadata: &TableMetadata, ) -> Result<Self>
Updates the metadata location with the metadata directory and compression settings from the new metadata.
Sourcepub fn compression_codec(&self) -> CompressionCodec
pub fn compression_codec(&self) -> CompressionCodec
Returns the compression codec used for this metadata location.