pub struct SessionContext { /* private fields */ }Expand description
Context for a session.
Example
use iceberg::SessionContext;
let session = SessionContext::builder()
.identity("user123".to_string())
.build();
assert_eq!(session.identity(), Some("user123"));
assert!(!session.session_id().is_empty());Implementations
Sourceimpl SessionContext
impl SessionContext
Sourcepub fn builder() -> SessionContextBuilder<((), (), (), ())>
pub fn builder() -> SessionContextBuilder<((), (), (), ())>
Create a builder for building SessionContext.
On the builder, call .session_id(...)(optional), .identity(...)(optional), .properties(...)(optional), .credentials(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of SessionContext.
Sourceimpl SessionContext
impl SessionContext
Sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
Returns the identifier for this session.
The identifier may be used for caching state within a session.
Sourcepub fn identity(&self) -> Option<&str>
pub fn identity(&self) -> Option<&str>
Returns a string that identifies the current user or principal.
Sourcepub fn properties(&self) -> &HashMap<String, String>
pub fn properties(&self) -> &HashMap<String, String>
Returns a map of properties currently set for the session.
Sourcepub fn credentials(&self) -> &HashMap<String, Credential>
pub fn credentials(&self) -> &HashMap<String, Credential>
Returns the session’s credential map.