pub struct Table { /* private fields */ }Expand description
Table represents a table in the catalog.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn builder() -> TableBuilder
pub fn builder() -> TableBuilder
Returns a TableBuilder to build a table
Sourcepub fn identifier(&self) -> &TableIdent
pub fn identifier(&self) -> &TableIdent
Returns table identifier.
Sourcepub fn metadata(&self) -> &TableMetadata
pub fn metadata(&self) -> &TableMetadata
Returns current metadata.
Sourcepub fn metadata_ref(&self) -> TableMetadataRef
pub fn metadata_ref(&self) -> TableMetadataRef
Returns current metadata ref.
Sourcepub fn metadata_location(&self) -> Option<&str>
pub fn metadata_location(&self) -> Option<&str>
Returns current metadata location.
Sourcepub fn metadata_location_result(&self) -> Result<&str>
pub fn metadata_location_result(&self) -> Result<&str>
Returns current metadata location in a result.
Sourcepub fn encryption_manager(&self) -> Option<&EncryptionManager>
pub fn encryption_manager(&self) -> Option<&EncryptionManager>
Returns the EncryptionManager for this table, if encryption is
configured.
A manager is present iff the table metadata has the
encryption.key-id property set and a KeyManagementClient was
supplied to the TableBuilder.
Sourcepub fn scan(&self) -> TableScanBuilder<'_>
pub fn scan(&self) -> TableScanBuilder<'_>
Creates a table scan.
Sourcepub fn inspect(&self) -> MetadataTable<'_>
pub fn inspect(&self) -> MetadataTable<'_>
Creates a metadata table which provides table-like APIs for inspecting metadata.
See MetadataTable for more details.
Sourcepub fn readonly(&self) -> bool
pub fn readonly(&self) -> bool
Returns the flag indicating whether the Table is readonly or not
Sourcepub fn current_schema_ref(&self) -> SchemaRef
pub fn current_schema_ref(&self) -> SchemaRef
Returns the current schema as a shared reference.
Sourcepub fn manifest_list_reader(&self, snapshot: &SnapshotRef) -> ManifestListReader
pub fn manifest_list_reader(&self, snapshot: &SnapshotRef) -> ManifestListReader
Creates a ManifestListReader for the given snapshot.
Sourcepub fn reader_builder(&self) -> ArrowReaderBuilder
pub fn reader_builder(&self) -> ArrowReaderBuilder
Create a reader for the table.