pub struct TableBuilder { /* private fields */ }Expand description
Builder to create table scan.
Implementations
Sourceimpl TableBuilder
impl TableBuilder
Sourcepub fn file_io(self, file_io: FileIO) -> Self
pub fn file_io(self, file_io: FileIO) -> Self
required - sets the necessary FileIO to use for the table
Sourcepub fn metadata_location<T: Into<String>>(self, metadata_location: T) -> Self
pub fn metadata_location<T: Into<String>>(self, metadata_location: T) -> Self
optional - sets the tables metadata location
Sourcepub fn metadata<T: Into<TableMetadataRef>>(self, metadata: T) -> Self
pub fn metadata<T: Into<TableMetadataRef>>(self, metadata: T) -> Self
required - passes in the TableMetadata to use for the Table
Sourcepub fn identifier(self, identifier: TableIdent) -> Self
pub fn identifier(self, identifier: TableIdent) -> Self
required - passes in the TableIdent to use for the Table
Sourcepub fn readonly(self, readonly: bool) -> Self
pub fn readonly(self, readonly: bool) -> Self
specifies if the Table is readonly or not (default not)
Sourcepub fn disable_cache(self) -> Self
pub fn disable_cache(self) -> Self
specifies if the Table’s metadata cache will be disabled, so that reads of Manifests and ManifestLists will never get cached.
Sourcepub fn cache_size_bytes(self, cache_size_bytes: u64) -> Self
pub fn cache_size_bytes(self, cache_size_bytes: u64) -> Self
optionally set a non-default metadata cache size
Sourcepub fn runtime(self, runtime: Runtime) -> Self
pub fn runtime(self, runtime: Runtime) -> Self
Set the Runtime for this table to use when spawning tasks.
Sourcepub fn kms_client(self, kms_client: Arc<dyn KeyManagementClient>) -> Self
pub fn kms_client(self, kms_client: Arc<dyn KeyManagementClient>) -> Self
optional - sets the KMS client used to unwrap keys for table encryption.
If the table metadata has the encryption.key-id property set, a
KeyManagementClient must be provided here so the table can build
an EncryptionManager; otherwise Self::build will return an error.