pub struct UpdatePropertiesAction { /* private fields */ }Expand description
A transactional action that updates or removes table properties
This action is used to modify key-value pairs in a table’s metadata properties during a transaction. It supports setting new values for existing keys or adding new keys, as well as removing existing keys. Each key can only be updated or removed in a single action, not both.
Implementations
Sourceimpl UpdatePropertiesAction
impl UpdatePropertiesAction
Sourcepub fn set(self, key: String, value: String) -> Self
pub fn set(self, key: String, value: String) -> Self
Adds a key-value pair to the update set of this action.
Arguments
key- The property key to update.value- The new value to associate with the key.
Returns
The updated UpdatePropertiesAction with the key-value pair added to the update set.