pub struct UpdateStatisticsAction { /* private fields */ }Expand description
A transactional action for updating statistics files in a table
Implementations
Sourceimpl UpdateStatisticsAction
impl UpdateStatisticsAction
Sourcepub fn set_statistics(self, statistics_file: StatisticsFile) -> Self
pub fn set_statistics(self, statistics_file: StatisticsFile) -> Self
Set the table’s statistics file for given snapshot, replacing the previous statistics file for the snapshot if any exists. The snapshot id of the statistics file will be used.
Arguments
statistics_file- TheStatisticsFileto associate with its corresponding snapshot ID.
Returns
An updated UpdateStatisticsAction with the new statistics file applied.
Sourcepub fn remove_statistics(self, snapshot_id: i64) -> Self
pub fn remove_statistics(self, snapshot_id: i64) -> Self
Remove the table’s statistics file for given snapshot.
Arguments
snapshot_id- The ID of the snapshot whose statistics file should be removed.
Returns
An updated UpdateStatisticsAction with the removal operation recorded.