pub struct UpgradeFormatVersionAction { /* private fields */ }Expand description
A transaction action to upgrade a table’s format version.
This action is used within a transaction to indicate that the
table’s format version should be upgraded to a specified version.
The location remains optional until explicitly set via UpgradeFormatVersionAction::set_format_version.
Implementations
Sourceimpl UpgradeFormatVersionAction
impl UpgradeFormatVersionAction
Sourcepub fn set_format_version(self, format_version: FormatVersion) -> Self
pub fn set_format_version(self, format_version: FormatVersion) -> Self