Struct ArrowReaderBuilder

pub struct ArrowReaderBuilder { /* private fields */ }
Builder to create ArrowReader

Implementations

Source

impl ArrowReaderBuilder

pub fn new(file_io: FileIO) -> Self

Create a new ArrowReaderBuilder

pub fn with_data_file_concurrency_limit(self, val: usize) -> Self

Sets the max number of in flight data files that are being fetched

pub fn with_batch_size(self, batch_size: usize) -> Self

Sets the desired size of batches in the response to something other than the default

pub fn with_row_group_filtering_enabled( self, row_group_filtering_enabled: bool, ) -> Self

Determines whether to enable row group filtering.

pub fn with_row_selection_enabled(self, row_selection_enabled: bool) -> Self

Determines whether to enable row selection.

pub fn with_metadata_size_hint(self, metadata_size_hint: usize) -> Self

Provide a hint as to the number of bytes to prefetch for parsing the Parquet metadata

This hint can help reduce the number of fetch requests. For more details see the ParquetMetaDataReader documentation.

pub fn build(self) -> ArrowReader

Build the ArrowReader.