pub enum CompressionCodec {
None,
Lz4,
Zstd(u8),
Gzip(u8),
Snappy,
}Expand description
Data compression formats
Variants
None
No compression
Lz4
LZ4 single compression frame with content size present
Zstd(u8)
Zstandard single compression frame with content size present.
Level range is 0–22, where 0 means default compression level (not no compression).
Use CompressionCodec::zstd_default to construct with the default level.
Gzip(u8)
Gzip compression. Level range is 0–9, where 0 means no compression.
Use CompressionCodec::gzip_default to construct with the default level.
Snappy
Snappy compression
Implementations
Sourceimpl CompressionCodec
impl CompressionCodec
Sourcepub const fn zstd_default() -> Self
pub const fn zstd_default() -> Self
Returns a Zstd codec with the default compression level.
Sourcepub const fn gzip_default() -> Self
pub const fn gzip_default() -> Self
Returns a Gzip codec with the default compression level.