pub struct FileScanTaskDeleteFile {
pub file_path: String,
pub file_size_in_bytes: u64,
pub file_type: DataContentType,
pub partition_spec_id: i32,
pub equality_ids: Option<Vec<i32>>,
pub key_metadata: Option<Box<[u8]>>,
}Expand description
A task to scan part of file.
Fields
file_path: StringThe delete file path
file_size_in_bytes: u64The total size of the delete file in bytes, from the manifest entry.
file_type: DataContentTypedelete file type
partition_spec_id: i32partition id
equality_ids: Option<Vec<i32>>equality ids for equality deletes (null for anything other than equality-deletes)
key_metadata: Option<Box<[u8]>>Key metadata for encrypted delete files (Parquet Modular Encryption).
When present, the reader uses this to build FileDecryptionProperties.
Same plaintext-DEK trust boundary as FileScanTask::key_metadata:
this is serialized into the scan plan and crosses the planner -> worker
channel in the clear for the standard encryption scheme.
Implementations
Sourceimpl FileScanTaskDeleteFile
impl FileScanTaskDeleteFile
Sourcepub fn builder() -> FileScanTaskDeleteFileBuilder<((), (), (), (), (), ())>
pub fn builder() -> FileScanTaskDeleteFileBuilder<((), (), (), (), (), ())>
Create a builder for building FileScanTaskDeleteFile.
On the builder, call .file_path(...), .file_size_in_bytes(...), .file_type(...), .partition_spec_id(...), .equality_ids(...)(optional), .key_metadata(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FileScanTaskDeleteFile.