pub struct MetadataLocation { /* private fields */ }Expand description
Helper for parsing a location of the format: <location>/metadata/<version>-<uuid>.metadata.json
or with compression: <location>/metadata/<version>-<uuid>.gz.metadata.json
Implementations
Sourceimpl MetadataLocation
impl MetadataLocation
Sourcepub fn new_with_table_location(table_location: impl ToString) -> Self
👎Deprecated since 0.8.0: Use new_with_metadata instead to properly handle compression settings
pub fn new_with_table_location(table_location: impl ToString) -> Self
Creates a completely new metadata location starting at version 0.
Only used for creating a new table. For updates, see next_version.
Sourcepub fn new_with_metadata(
table_location: impl ToString,
metadata: &TableMetadata,
) -> Self
pub fn new_with_metadata( table_location: impl ToString, metadata: &TableMetadata, ) -> Self
Creates a completely new metadata location starting at version 0,
with compression settings from the table metadata.
Only used for creating a new table. For updates, see next_version.
Sourcepub fn with_next_version(&self) -> Self
pub fn with_next_version(&self) -> Self
Creates a new metadata location for an updated metadata file. Increments the version number and generates a new UUID.
Sourcepub fn with_new_metadata(&self, new_metadata: &TableMetadata) -> Self
pub fn with_new_metadata(&self, new_metadata: &TableMetadata) -> Self
Updates the metadata location with compression settings from the new metadata.
Sourcepub fn compression_codec(&self) -> CompressionCodec
pub fn compression_codec(&self) -> CompressionCodec
Returns the compression codec used for this metadata location.